define(["require", "exports", "async-middleware", "@essential-projects/http_node", "@process-engine/consumer_api_contracts", "../../middlewares/index"], function (require, exports, async_middleware_1, http_node_1, consumer_api_contracts_1, index_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    class ExternalTaskRouter extends http_node_1.BaseRouter {
        constructor(externalTaskController, identityService) {
            super();
            this.externalTaskController = externalTaskController;
            this.identityService = identityService;
        }
        get baseRoute() {
            return 'api/consumer/v1';
        }
        async initializeRouter() {
            this.registerMiddlewares();
            const controller = this.externalTaskController;
            this.router.post(consumer_api_contracts_1.restSettings.paths.fetchAndLockExternalTasks, async_middleware_1.wrap(controller.fetchAndLockExternalTasks.bind(controller)));
            this.router.post(consumer_api_contracts_1.restSettings.paths.extendExternalTaskLock, async_middleware_1.wrap(controller.extendLock.bind(controller)));
            this.router.post(consumer_api_contracts_1.restSettings.paths.finishExternalTaskWithBpmnError, async_middleware_1.wrap(controller.handleBpmnError.bind(controller)));
            this.router.post(consumer_api_contracts_1.restSettings.paths.finishExternalTaskWithServiceError, async_middleware_1.wrap(controller.handleServiceError.bind(controller)));
            this.router.post(consumer_api_contracts_1.restSettings.paths.finishExternalTask, async_middleware_1.wrap(controller.finishExternalTask.bind(controller)));
        }
        registerMiddlewares() {
            const resolveIdentity = index_1.createResolveIdentityMiddleware(this.identityService);
            this.router.use(async_middleware_1.wrap(resolveIdentity));
        }
    }
    exports.ExternalTaskRouter = ExternalTaskRouter;
});
//# sourceMappingURL=external_task_router.js.map